<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca_ES">
<context>
    <name>About</name>
    <message>
        <location filename="../src/about.ui" line="26"/>
        <location filename="../src/about.cpp" line="37"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="82"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:700;&quot;&gt;UltimateDailyWallpaper&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="89"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Version: &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="133"/>
        <source>tab0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="178"/>
        <source>label_4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="191"/>
        <source>label_5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="204"/>
        <source>label_6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="230"/>
        <source>tab1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="257"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="316"/>
        <source>pushButton_3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="335"/>
        <source>pushButton</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="38"/>
        <source>Currently used plugin</source>
        <translation>Plugin utilitzat</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="44"/>
        <source>License: GPL-3.0+</source>
        <translation>Llicència: GPL-3.0+</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="48"/>
        <source>Version: </source>
        <translation>Versió: </translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="54"/>
        <source>Patrice Coni</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="56"/>
        <source>Copyright © 2022 - </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="62"/>
        <source>A wallpaper changer</source>
        <translation>Una aplicació per canviar el fons de pantalla</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="64"/>
        <source>Close</source>
        <translation>Tancar</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="65"/>
        <source>Visit website</source>
        <translation>Visita el lloc web</translation>
    </message>
    <message>
        <source>A simple application for changing wallpaper</source>
        <translation type="vanished">Una aplicació senzilla per canviar fons de pantalla</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="93"/>
        <source>No connection to the internet.
The application will be closed.</source>
        <translation>Sense connexió a internet.
La sol·licitud estarà tancada.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="119"/>
        <source>Reset</source>
        <translation>Reinicialitzar</translation>
    </message>
    <message>
        <source>The folder that containing the plugins was not found. Do you want to set the folder manually?</source>
        <translation type="vanished">No s&apos;ha trobat la carpeta que conté els plugins. Voleu configurar la carpeta manualment?</translation>
    </message>
    <message>
        <source>Select directory</source>
        <translation type="obsolete">Seleccionar directori</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="119"/>
        <source>The folder containing the plugins was not found. Do you want to set the folder manually?</source>
        <translation>No s&apos;ha trobat la carpeta que conté els complements. Voleu definir la carpeta manualment?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="125"/>
        <source>Select Plugin Folder</source>
        <translation>Selecciona el directori</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="134"/>
        <source>No Plugins Found</source>
        <translation>No s&apos;han trobat complements</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="135"/>
        <source>The folder does not contain any plugin files (*.so). Please choose a valid plugin folder.</source>
        <translation>El directori no conté cap fitxer de complement. Trieu una carpeta de complements vàlida.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="323"/>
        <location filename="../src/mainwindow.cpp" line="334"/>
        <location filename="../src/mainwindow.cpp" line="811"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="323"/>
        <source>No plugins found.</source>
        <translation>No s&apos;han trobat connectors.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="329"/>
        <location filename="../src/mainwindow.cpp" line="806"/>
        <source>done.</source>
        <translation>fet.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="330"/>
        <location filename="../src/mainwindow.cpp" line="807"/>
        <source>Used plugin: </source>
        <translation>Plugin utilitzat: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="334"/>
        <location filename="../src/mainwindow.cpp" line="811"/>
        <source>Error while loading plugin.</source>
        <translation>Error en carregar el plugin.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="424"/>
        <source>An error was detected when starting the application.
The application will be closed.</source>
        <translation>S&apos;ha detectat un error en iniciar l&apos;aplicació.
La aplicació licitud estarà tancada.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="493"/>
        <source>No connection to the internet.</source>
        <translation>Sense connexió a internet.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="493"/>
        <source>Please check your internet connection.</source>
        <translation>Comproveu la vostra connexió a Internet.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="796"/>
        <source>&amp;Provider</source>
        <translation>&amp;Proveïdor</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="834"/>
        <source>&amp;About this picture and license</source>
        <translation>&amp;Sobre aquesta imatge i llicència</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="838"/>
        <source>&amp;About this picture and copyright</source>
        <translation>&amp;Sobre aquesta imatge i els drets d&apos;autor</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="845"/>
        <source>&amp;Download past pictures</source>
        <translation>&amp;Descarregar imatges anteriors</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="849"/>
        <source>&amp;Load stored picture</source>
        <translation>&amp;Carrega la imatge emmagatzemada</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="852"/>
        <source>&amp;Settings</source>
        <translation>&amp;Configuració</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="855"/>
        <source>&amp;About</source>
        <translation>&amp;Sobre</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="858"/>
        <source>&amp;Quit</source>
        <translation>&amp;Sortir</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="873"/>
        <source>No internet connection.</source>
        <translation>Sense connexió a Internet.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="932"/>
        <source>Description: 
</source>
        <translation>Descripció: 
</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1256"/>
        <source>Offline</source>
        <translation>Offline</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1257"/>
        <source>No internet connection available.</source>
        <translation>Sense connexió a Internet.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1518"/>
        <source>Load plugin...</source>
        <translation>Carrega el plugin...</translation>
    </message>
</context>
<context>
    <name>PhotoBrowser</name>
    <message>
        <location filename="../src/photobrowser.ui" line="20"/>
        <location filename="../src/photobrowser.ui" line="58"/>
        <source>Load stored picture</source>
        <translation>Carrega la imatge emmagatzemada</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="90"/>
        <location filename="../src/photobrowser.ui" line="187"/>
        <source>&amp;Set as wallpaper</source>
        <translation>&amp;Estableix com a fons de pantalla</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="174"/>
        <source>Select a photo</source>
        <translation>Selecciona una foto</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="282"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Select date: &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Seleccioneu la data: &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="325"/>
        <source>&amp;Set current date</source>
        <translation>&amp;Defineix la data actual</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="382"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Show photos of past days: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Mostra fotos de dies passats: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="449"/>
        <source>&amp;Show pictures</source>
        <translation>&amp;Mostra imatges</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="209"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="209"/>
        <source>Error while loading plugin.</source>
        <translation>Error en carregar el plugin.</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="214"/>
        <source>Past pictures of the day (Wikimedia Commons)</source>
        <translation>Imatges anteriors del dia (Wikimedia Commons)</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="263"/>
        <source>Get more information</source>
        <translation>Obtenir més informació</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="430"/>
        <source>Details</source>
        <translation>Detalls</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="434"/>
        <source>Please select a picture.</source>
        <translation>Seleccioneu una imatge.</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="442"/>
        <source>Title: </source>
        <translation>Títol: </translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="448"/>
        <source>Description: </source>
        <translation>Descripció: </translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="460"/>
        <source>Picture size:</source>
        <translation>Mida de la imatge:</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="470"/>
        <source>Preview:</source>
        <translation>Preestrena:</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="508"/>
        <source>Download in progress...</source>
        <translation>Descàrrega en curs...</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="551"/>
        <source>The entered date must not be in the future.</source>
        <translation>La data introduïda no ha de ser en el futur.</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="641"/>
        <source>Working in progress...</source>
        <translation>Treballant en progrés...</translation>
    </message>
</context>
<context>
    <name>QProgressDialog</name>
    <message>
        <source>Download in progress...</source>
        <translation type="vanished">Descàrrega en curs...</translation>
    </message>
    <message>
        <source>Working in progress...</source>
        <translation type="vanished">Treballant en progrés...</translation>
    </message>
</context>
<context>
    <name>SettingsWindow</name>
    <message>
        <location filename="../src/settingswindow.ui" line="23"/>
        <source>Settings</source>
        <translation>Configuració</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="37"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Location to save background photos: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ubicació per desar fotos de fons: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="55"/>
        <source>Choose</source>
        <translation>Triar</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="72"/>
        <source>Delete wallpapers older than (days): </source>
        <translation>Elimineu fons de pantalla més antics que (dies): </translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="121"/>
        <source>Change desktop background photo automatically</source>
        <translation>Canviar automàticament la foto de fons de l&apos;escriptori</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="141"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Time of day for changing wallpaper automatically: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Hora del dia per canviar el fons de pantalla automàticament: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="181"/>
        <source>Run Application at startup</source>
        <translation>Executeu l&apos;aplicació a l&apos;inici</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="198"/>
        <source>Change lock screen wallpaper if possible</source>
        <translation>Canvieu el fons de pantalla de bloqueig si és possible</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="240"/>
        <location filename="../src/settingswindow.cpp" line="176"/>
        <source>Reset</source>
        <translation>Reinicialitzar</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="272"/>
        <source>Save settings</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="291"/>
        <source>Cancel</source>
        <translation>Cancel·lar</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="141"/>
        <source>Save changes</source>
        <translation>Desa els canvis</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="141"/>
        <source>The application will be restart for the changes to take effect. Do you want save the changes?</source>
        <translation>Es reiniciarà l&apos;aplicació perquè els canvis entrin en vigor. Vols guardar els canvis?</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="155"/>
        <source>Select directory</source>
        <translation>Seleccionar directori</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="176"/>
        <source>This will reset all settings to the default settings. All existing wallpapers will be deleted. Do you want to continue?</source>
        <translation>Això restablirà tots els paràmetres a la configuració predeterminada. Se suprimiran tots els fons de pantalla existents. Vols continuar?</translation>
    </message>
</context>
<context>
    <name>setWallpaper</name>
    <message>
        <location filename="../src/setwallpaper.cpp" line="207"/>
        <source>Error: Failed to set wallpaper on macOS.</source>
        <translation>Error en carregar fons de pantalla.</translation>
    </message>
    <message>
        <location filename="../src/setwallpaper.cpp" line="218"/>
        <source>Error - Failed to set wallpaper.</source>
        <translation>Error en carregar fons de pantalla.</translation>
    </message>
</context>
</TS>
